/****************************************************************************
 *                                                                          *
 * File    : hyperlink.h                                                    *
 *                                                                          *
 * Purpose : Hyperlink custom control external interface.                   *
 *                                                                          *
 * History : Date      Reason                                               *
 *           00/00/00  Created                                              *
 *                                                                          *
 ****************************************************************************/

#ifndef _hyperlink_h_
#define _hyperlink_h_

#include <shellapi.h>
#pragma comment(lib, "shell32.lib")

/** Class name **************************************************************/

#define HYPERLINK_CLASS _T("HyperlinkCtrl32")

/** Messages ****************************************************************/

#define HLM_SETTOOLTIP       (WM_USER + 0x100)
#define HLM_GETTOOLTIP       (WM_USER + 0x101)
#define HLM_GETTOOLTIPLENGTH (WM_USER + 0x102)
#define HLM_SETFGCOLORS      (WM_USER + 0x103)
#define HLM_SETBGCOLORS      (WM_USER + 0x104)

/** Notifications ***********************************************************/

#define HLN_CLICKED 0

/** Styles ******************************************************************/

#define HLS_LEFT       0x0001L
#define HLS_HCENTER    0x0002L
#define HLS_RIGHT      0x0004L

#define HLS_TOP        0x0010L
#define HLS_VCENTER    0x0020L
#define HLS_BOTTOM     0x0040L

#define HLS_ULALWAYS   0x0100L
#define HLS_ULNONE     0x0200L
#define HLS_ULHOVER    0x0400L

#define HLS_PLAYCLICK  0x1000L
#define HLS_AUTOSIZE   0x2000L

#define HLS_STANDARD (HLS_LEFT | HLS_TOP | HLS_ULHOVER | HLS_PLAYCLICK)

/** Message APIs ************************************************************/

#define Hyperlink_Create(text, style, x, y, width, height, hwndParent, id) \
    CreateWindow((LPCTSTR) HYPERLINK_CLASS, (LPCTSTR) text, (DWORD) style, \
        (int) x, (int) y, (int) width, (int) height, (HWND) hwndParent, (HMENU) id, \
            (HINSTANCE) GetModuleHandle(NULL), NULL)

#define Hyperlink_Show(hwnd, fShow) \
    ShowWindow(hwnd, (fShow) ? SW_SHOW : SW_HIDE)

#define Hyperlink_Enable(hwnd, fEnable) \
    EnableWindow((hwnd), (fEnable))

#define Hyperlink_SetText(hwnd, lpsz) \
    SetWindowText((hwnd), (lpsz))

#define Hyperlink_GetText(hwnd, lpsz, cchMax) \
    GetWindowText((hwnd), (lpsz), (cchMax))

#define Hyperlink_GetTextLength(hwnd) \
    GetWindowTextLength(hwnd)

#define Hyperlink_SetFont(hwnd, hfont) \
    SetWindowFont(hwnd, hfont, FALSE)

#define Hyperlink_GetFont(hwnd) \
    GetWindowFont(hwnd)

#define Hyperlink_SetTooltip(hwnd, lpsz) \
    ((void)SNDMSG((hwnd), HLM_SETTOOLTIP, 0, (LPARAM)(LPCTSTR)(lpsz)))

#define Hyperlink_GetTooltip(hwnd, lpsz, cchMax) \
    ((LRESULT)(DWORD)(int)SNDMSG((hwnd), HLM_GETTOOLTIP, \
        (WPARAM)(int)(cchMax), (LPARAM)(LPTSTR)(lpsz)))

#define Hyperlink_GetTooltipLength(hwnd) \
    (LRESULT)(DWORD)(int)SNDMSG((hwnd), HLM_GETTOOLTIPLENGTH, 0, 0))

#define Hyperlink_SetFgColors(hwnd, fgcNormal, fgcHover) \
    ((void)SNDMSG((hwnd), HLM_SETFGCOLORS, \
        (WPARAM)(COLORREF)(fgcNormal), (LPARAM)(COLORREF)(fgcHover)))

#define Hyperlink_SetBgColors(hwnd, bgcNormal, bgcHover) \
    ((void)SNDMSG((hwnd), HLM_SETBGCOLORS, \
        (WPARAM)(COLORREF)(bgcNormal), (LPARAM)(COLORREF)(bgcHover)))

#define Hyperlink_OpenUrl(lpsz) \
    ShellExecute(NULL, _T("open"), lpsz, NULL, NULL, SW_SHOWNORMAL)

/** Prototypes **************************************************************/

BOOL Hyperlink_RegisterClass(void);
BOOL Hyperlink_UnregisterClass(void);

#endif
